const express = require("express");
const bodyParser = require("body-parser");
const cors = require("cors");

const { createProduct, getProducts, putProduct, deleteProduct, getProductById } = require('./controllers/product.controller');
const { createCategory, getCategories, putCategory, deleteCategory, getCategoriesbyId } = require('./controllers/category.controller');

const app = express();
const PORT = 9000;

app.use(cors({
    origin: "http://localhost:5173",
    methods: ["GET", "POST", "PUT", "DELETE"],
    allowedHeaders: ["Content-Type", "Authorization"]
}));

app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: false }));

// products API routes
app.post("/api/products", createProduct);
app.get("/api/products", getProducts);
app.get("/api/products/:id", getProductById);

app.put("/api/products/:id", putProduct);
app.delete("/api/products/:id", deleteProduct);

// category API routes
app.post("/api/categories", createCategory);
app.get("/api/categories", getCategories);
app.get("/api/categories/:id", getCategoriesbyId);

app.put("/api/categories/:id", putCategory);
app.delete("/api/categories/:id", deleteCategory);



app.listen(PORT, () => {
    console.log(`Server is running on port ${PORT}`);
});
