import { useEffect, useState } from "react";
import { fetchCategories } from "../services/api";
import { Link } from "react-router-dom";

const Categories = () => {
  const [categories, setCategories] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const data = await fetchCategories();
      console.log(data, "Fetched categories");
      setCategories(data);
    };
    fetchData();
  }, []);

  return (
    <div className="p-5">
      <h1 className="text-2xl font-bold mb-4">Categories</h1>
      <div className="grid grid-cols-3 gap-5">
        <h3 className="grid grid-cols-3 gap-5"></h3>
        {categories.map((category) => (
          <Link
            key={category.id}
            to={`/categories/${category.id}`}
            className="p-4 bg-gray-200 border rounded-lg hover:shadow-lg"
          >
            <div>
              <ul>
                <li>
                  <img
                    src={category.image}
                    alt={category.name}
                    className="w-full h-32 object-cover mb-3"
                  />
                </li>
              </ul>
              <h2 className="text-lg font-semibold">{category.name}</h2>
              <p className="text-sm">{category.description}</p>
            </div>
          </Link>
        ))}
      </div>
    </div>
  );
};

export default Categories;
