import { useEffect, useState } from "react";
import { fetchProductsByCategory } from "../services/api";
import { Link, useParams } from "react-router-dom";

const CategoryProducts = () => {
  const { id } = useParams();
  const [products, setProducts] = useState([]);

  useEffect(() => {
    const fetchData = async () => {
      const data = await fetchProductsByCategory(id);
      setProducts(data);
    };
    fetchData();
  }, [id]);

  return (
    <div className="p-5">
      <h1 className="text-2xl font-bold mb-4">Products</h1>
      <div className="grid grid-cols-3 gap-5">
        {products?.map((product) => (
          <Link
            key={product.id}
            to={`/products/${product?.id}`}
            className="p-4 bg-gray-200 border rounded-lg hover:shadow-lg"
          >
            <div>
              <ul>
                <li>
                  <img
                    src={product?.image}
                    alt={product?.description}
                    className="w-full h-32 object-cover mb-3"
                  />
                  <h2 className="text-lg font-semibold">{product?.name}</h2>
                  <p className="text-sm">{product?.description}</p>
                </li>
              </ul>
            </div>
          </Link>
        ))}
      </div>
    </div>
  );
};

export default CategoryProducts;
